"""
Minimales Beispiel Plugin - Active Layer Search

class ActiveLayerSearch definiert das Plugin. 
Es gibt darin 3 Bloecke ('Methoden')... 
- initGui: platziert das Plugin... "Was passiert, wenn man das Haekchen setzt"...
- unload: entfernt das Plugin ... ""
- __init__: muss da sein, ermoeglicht den Zugriff auf die Benutzeroberflaeche von QGIS

class SearchDialog definiert die GUI (Dialogfenster das wir gerade gesehen haben)
"""


# Import von Python Funktionen, die wir fuer das Plugin brauchen
import os
from PyQt5 import uic
from PyQt5.QtWidgets import QAction
from PyQt5.QtGui import QIcon

# ActiveLayerSearch definiert das Plugin


class ActiveLayerSearch:

    # __init__ muss immer da sein
    # self.iface => Zugriff auf die Benutzeroberflaeche von QGIS
    def __init__(self, iface):
        self.iface = iface

        # Die Methode initGui muss immer da sein
        # Wird ausgefuehrt, wenn das Haekchen gesetzt wird
    def initGui(self):

        # Pfad zum Icon
        icon_path = os.path.join(os.path.dirname(__file__), 'icon.svg')

        # Diese zwei Zeilen sorgen dafuer, dass das Plugin im Plugin Menu erscheint
        self.action_search = QAction(QIcon(icon_path), 'Suche starten', self.iface.mainWindow())
        self.iface.addPluginToMenu("&Active Layer Search", self.action_search)
        self.iface.addToolBarIcon(self.action_search)

        # Diese Zeile sorgt dafuer, dass das Plugin gestartet wird,
        # wenn man auf den Button klickt
        # Dabei wird die Methode start_search ausgefuehrt
        self.action_search.triggered.connect(self.start_search)

        # Die Methode unload muss immer da sein
        # Wird ausgefuehrt, wenn das Haekchen vom Plugin entfernt wird
    def unload(self):
        self.iface.removePluginMenu("&Active Layer Search", self.action_search)
        self.iface.removeToolBarIcon(self.action_search)

    def start_search(self):
        """Wird ausgeführt beim Klick auf die Aktion (Menüeintrag)"""

        # Dialog erstellen
        self.search_dialog = SearchDialog()

        # Bei einem Klick auf den Button wird die
        # Suche gestartet
        self.search_dialog.pushButton.clicked.connect(self.layer_search)

        # Dialog zeigen / ausführen
        self.search_dialog.exec()

    def layer_search(self):

        # Nutzereingabe auslesen
        searchtext = self.search_dialog.lineEdit.text()

        # Skript einfuegen und anpassen
        lyr = self.iface.activeLayer()
        feats = lyr.getFeatures()

        for feat in feats:
            attrs = feat.attributes()
            if searchtext in str(attrs):
                fid = feat.id()
                lyr.selectByIds([fid])
                self.iface.actionZoomToSelected().trigger()
                break


# Dialog aus .ui-Datei
WIDGET, BASE = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'search_dialog.ui'))


class SearchDialog(BASE, WIDGET):

    def __init__(self, parent=None):
        super().__init__(parent)
        self.setupUi(self)
